"""Plugin for generic approval flows."""

from django.core.validators import MinValueValidator
from django.utils.translation import ugettext_lazy as _
from plugin import InvenTreePlugin
from plugin.mixins import AppMixin, NavigationMixin, SettingsMixin, UrlsMixin


class ApprovalPlugin(
    AppMixin, SettingsMixin, UrlsMixin, NavigationMixin, InvenTreePlugin
):
    """Plugin for generic approval flows."""

    NAME = "ApprovalPlugin"
    SLUG = "inventree_approval"
    TITLE = "Approvals"
    SETTINGS = {
        "APPROVAL_MINIMUM_APPROVERS": {
            "name": _("Minimum Approvers"),
            "description": _("Minimum number of approvers required for approval"),
            "default": 2,
            "validator": [int, MinValueValidator(1)],
        },
        "APPROVAL_MAXIMUM_DENIERS": {
            "name": _("Maximum Deniers"),
            "description": _("Maximum number of deniers required for denial"),
            "default": 1,
            "validator": [int, MinValueValidator(1)],
        },
    }

    def setup_urls(self):
        """Setup url endpoints for this plugin."""
        from .api import urlpatterns

        return urlpatterns
